==> tqsdk2-1.2.9-cp37-cp37m-win_amd64.whl: tqsdk2/__init__.py <==
#!/usr/bin/env python
#  -*- coding: utf-8 -*-
name = "tqsdk2"

import os, ctypes
import os, platform

this_dir = os.path.abspath(os.path.dirname(__file__))
dll_list = []

if platform.system() == "Windows":
    dll_list = ["lib/WinDataCollect.dll",
                "lib/oes_api.dll", 
                'lib/thosttraderapi.dll',
                'lib/thosttraderapi_se.dll',
                'lib/mfc100.dll',
                'lib/msvcp100.dll',
                'lib/msvcr100.dll',
                'lib/RohonBaseV64.dll',
                'lib/thosttraderapi_rh.dll',
                'lib/cjson.dll',
                'lib/zlib1.dll',
                'lib/bz2.dll',
                'lib/lzma.dll',
                'lib/zstd.dll',
                'lib/boost_iostreams-vc142-mt-x64-1_73.dll',
                'lib/libuv.dll',
                'lib/libcurl.dll',
                'lib/sqlite3.dll',
                'lib/uSockets.dll',
                'lib/libcrypto-1_1-x64.dll',
                'lib/libssl-1_1-x64.dll',
                'lib/uriparser.dll',
                'lib/fclib.dll'
                ]
else:
    dll_list = ["lib/LinuxDataCollect.so",
                "lib/libLinuxDataCollect.so",                
                "lib/libdatafeed64.so",
                "lib/liboes_api.so", 
                "lib/libthosttraderapi.so",
                "lib/libthosttraderapi_se.so",
                "lib/librohonbase.so",
                "lib/librohonbase.so.1.1",
                "lib/libthosttraderapi20200106zip.so",
                "lib/libfclib.so"
                ]

os.environ['TQSDK2_WEB_PATH'] = os.path.join(this_dir, 'web')
for name in dll_list:
    ctypes.cdll.LoadLibrary(os.path.join(this_dir, name))

from tqsdk2.tqsdk2 import TqApi
from tqsdk2.tqsdk2 import TqAuth
from tqsdk2.tqsdk2 import TqAccount, TqCtp, TqSim, TqKq, TqRohon
from tqsdk2.tqsdk2 import TargetPosTask, TqBacktest, BacktestFinished

from tqsdk2.tqsdk2 import ta

==> tqsdk2-1.5.7-cp37-cp37m-win_amd64.whl: tqsdk2/__init__.py <==
#!/usr/bin/env python
#  -*- coding: utf-8 -*-
name = "tqsdk2"

import os, ctypes
import os, platform
try:
    import pandas as pd
except ImportError as e:
    err_msg = """
    当遇到此问题时，如果您是 windows 用户，可能是您的环境缺少 C++ 运行库，可以尝试以下解决方案之一，再重新运行程序即可。
    1. 到微软官网下载您机器上安装 python 对应版本的 vc_redist 文件运行安装即可。https://www.microsoft.com/en-us/download/details.aspx?id=48145 
       vc_redist.x64.exe（64 位 python）、 vc_redist.x86.exe（32 位 python）
    """
    raise Exception(err_msg)

this_dir = os.path.abspath(os.path.dirname(__file__))
dll_list = []

if platform.system() == "Windows":
    dll_list = ["lib/WinDataCollect.dll",
                "lib/oes_api.dll", 
                'lib/thosttraderapi.dll',
                'lib/thosttraderapi_se.dll',
                'lib/mfc100.dll',
                'lib/msvcp100.dll',
                'lib/msvcr100.dll',
                'lib/RohonBaseV64.dll',
                'lib/thosttraderapi_rh.dll',
                'lib/zlib1.dll',
                'lib/bz2.dll',
                'lib/lzma.dll',
                'lib/zstd.dll',
                'lib/boost_iostreams-vc142-mt-x64-1_75.dll',
                'lib/libuv.dll',
                'lib/libcurl.dll',
                'lib/sqlite3.dll',
                'lib/uSockets.dll',
                'lib/libcrypto-1_1-x64.dll',
                'lib/libssl-1_1-x64.dll',
                'lib/uriparser.dll',
                'lib/fclib.dll'
                ]
else:
    dll_list = ["lib/libLinuxDataCollect.so",
                "lib/libLinuxDataCollect0.so",
                "lib/libdatafeed64.so",
                "lib/liboes_api.so", 
                "lib/libthosttraderapi.so",
                "lib/libthosttraderapi_se.so",
                "lib/librohonbase.so",
                "lib/librohonbase.so.1.1",
                "lib/libthosttraderapi20200106zip.so",
                "lib/libfclib.so"
                ]

os.environ['TQSDK2_WEB_PATH'] = os.path.join(this_dir, 'web')
for name in dll_list:
    ctypes.cdll.LoadLibrary(os.path.join(this_dir, name))

from tqsdk2.tqsdk2 import TqApi
from tqsdk2.tqsdk2 import TqAuth
from tqsdk2.tqsdk2 import TqAccount, TqCtp, TqSim, TqKq, TqRohon
from tqsdk2.tqsdk2 import TargetPosTask, TqBacktest, BacktestFinished
from tqsdk2.tqsdk2 import TqMarketMaker

from tqsdk2.tqsdk2 import ta
